@@ -24,6 +24,7 @@ use Composer\Package\PackageInterface;
 use Composer\Semver\Constraint\Constraint;
 use Composer\Test\Mock\FactoryMock;
 use Composer\Test\Mock\HttpDownloaderMock;
+use Composer\Test\Mock\IOMock;
 use Composer\Test\Mock\ProcessExecutorMock;
 use Composer\Util\Filesystem;
 use Composer\Util\Platform;
@@ -59,6 +60,10 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
      * @var list<ProcessExecutorMock>
      */
     private $processExecutorMocks = [];
+    /**
+     * @var list<IOMock>
+     */
+    private $ioMocks = [];
     /**
      * @var list<string>
      */
@@ -75,6 +80,9 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         foreach ($this->processExecutorMocks as $mock) {
             $mock->assertComplete();
         }
+        foreach ($this->ioMocks as $mock) {
+            $mock->assertComplete();
+        }
 
         if (null !== $this->prevCwd) {
             chdir($this->prevCwd);
@@ -114,9 +122,10 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
      * @see getApplicationTester
      * @param mixed[] $composerJson
      * @param mixed[] $authJson
+     * @param mixed[] $composerLock
      * @return string the newly created temp dir
      */
-    public function initTempComposer(array $composerJson = [], array $authJson = []): string
+    public function initTempComposer(array $composerJson = [], array $authJson = [], array $composerLock = []): string
     {
         $dir = self::getUniqueTmpDirectory();
 
@@ -142,6 +151,10 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         file_put_contents($dir.'/composer.json', JsonFile::encode($composerJson, JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
         file_put_contents($dir.'/auth.json', JsonFile::encode($authJson, JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
 
+        if ($composerLock !== []) {
+            file_put_contents($dir.'/composer.lock', JsonFile::encode($composerLock, JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
+        }
+
         return $dir;
     }
 
@@ -181,7 +194,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
     {
         $factory = new FactoryMock();
 
-        $locker = new Locker($this->getMockBuilder(IOInterface::class)->getMock(), new JsonFile('./composer.lock'), $factory->createInstallationManager(), (string) file_get_contents('./composer.json'));
+        $locker = new Locker($this->getIOMock(), new JsonFile('./composer.lock'), $factory->createInstallationManager(), (string) file_get_contents('./composer.json'));
         $locker->setLockData($packages, $devPackages, [], [], [], 'dev', [], false, false, []);
     }
 
@@ -190,6 +203,9 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         $application = new Application();
         $application->setAutoExit(false);
         $application->setCatchExceptions(false);
+        if (method_exists($application, 'setCatchErrors')) {
+            $application->setCatchErrors(false);
+        }
 
         return new ApplicationTester($application);
     }
@@ -356,6 +372,16 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         return $mock;
     }
 
+    /**
+     * @param IOInterface::* $verbosity
+     */
+    protected function getIOMock(int $verbosity = IOInterface::DEBUG): IOMock
+    {
+        $this->ioMocks[] = $mock = new IOMock($verbosity);
+
+        return $mock;
+    }
+
     protected function createTempFile(?string $dir = null): string
     {
         $dir = $dir ?? sys_get_temp_dir();
